﻿//  --------------------------------
//  Copyright (c) PK Logix LLC. All rights reserved.
//  This source code is made available under the terms of the GNU General Public License version 2 (GPLv2)
//  http://www.codeplex.com/mvcclubsite/license
//  ---------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MVCClubSite.Model;

namespace MVCClubSite.IDAL
{
    /// <summary>
    /// Interface for Events DAL
    /// </summary>
    public interface IEvents
    {
        /// <summary>
        /// Method to get events
        /// </summary>
        /// <returns></returns>
        IQueryable<Event> GetEvents();

        /// <summary>
        /// Method to get upcoming events
        /// </summary>
        /// <param name="days">Number of days in the future</param>
        /// <returns></returns>
        IQueryable<Event> GetUpcomingEvents();

        /// <summary>
        /// Method to get recent events
        /// </summary>
        /// <param name="days">Number of days in the past</param>
        /// <returns></returns>
        IQueryable<Event> GetRecentEvents();

        /// <summary>
        /// Method to get events on a certain date
        /// </summary>
        /// <param name="date">Date of the events</param>
        /// <returns></returns>
        IQueryable<Event> GetEventsByDate(DateTime date);

        /// <summary>
        /// Method to get a events by ID
        /// </summary>
        /// <param name="id">ID of the event</param>
        /// <returns>Event business entity</returns>
        Event GetEventByID(int id);

        /// <summary>
        /// Method to insert or update a event
        /// </summary>
        /// <param name="location">Event to insert or update</param>
        void Save(Event location);

        /// <summary>
        /// Method to delete a event
        /// </summary>
        /// <param name="id">ID of the event</param>
        void Delete(int id);
    }
}
